@@ -128,7 +128,7 @@ our string_hashref::method $ast_to_rperl__generate = sub {
         my string $property_subexpression_string;
 
         $property_key = $property_0->{children}->[0]->{children}->[0];
-        $property_key =~ s/^(\w+)\s*$/$1/gxms;    # remove trailing whitespace, caused by grammar matching operator names with trailing spaces
+        $property_key =~ s/^(\w+)\s*$/$1/gxms;    # strip trailing whitespace, caused by grammar matching operator names with trailing spaces
         if ( $property_key !~ /^[a-z]/ ) {
             die 'ERROR ECOGEASRP23, CODE GENERATOR, ABSTRACT SYNTAX TO RPERL: invalid OO properties name (hash key) ' . q{'}
                 . $property_key . q{'}
@@ -137,7 +137,7 @@ our string_hashref::method $ast_to_rperl__generate = sub {
         $property_fat_arrow  = $property_0->{children}->[1];
         $property_type_inner = $property_0->{children}->[2];
         $property_name       = $property_type_inner->{children}->[3]->{children}->[0];
-        $property_name =~ s/^(\w+)\s*$/$1/gxms;    # remove trailing whitespace, caused by grammar matching operator names with trailing spaces
+        $property_name =~ s/^(\w+)\s*$/$1/gxms;    # strip trailing whitespace, caused by grammar matching operator names with trailing spaces
 
         # DEV NOTE: we can do error checking once here instead of twice for TypeInnerProperties_223 & TypeInnerProperties_224 below
         # because they both have OpStringOrWord as sub-element 3, grabbed as $property_name above
@@ -208,7 +208,7 @@ our string_hashref::method $ast_to_rperl__generate = sub {
             }
             else {
                 $property_key = $property->{children}->[0]->{children}->[0];
-                $property_key =~ s/^(\w+)\s*$/$1/gxms;              # remove trailing whitespace, caused by grammar matching operator names with trailing spaces
+                $property_key =~ s/^(\w+)\s*$/$1/gxms;              # strip trailing whitespace, caused by grammar matching operator names with trailing spaces
                 if ( $property_key !~ /^[a-z]/ ) {
                     die 'ERROR ECOGEASRP23, CODE GENERATOR, ABSTRACT SYNTAX TO RPERL: invalid OO properties name (hash key) ' . q{'}
                         . $property_key . q{'}
@@ -217,7 +217,7 @@ our string_hashref::method $ast_to_rperl__generate = sub {
                 $property_fat_arrow  = $property->{children}->[1];
                 $property_type_inner = $property->{children}->[2];
                 $property_name       = $property_type_inner->{children}->[3]->{children}->[0];
-                $property_name =~ s/^(\w+)\s*$/$1/gxms;             # remove trailing whitespace, caused by grammar matching operator names with trailing spaces
+                $property_name =~ s/^(\w+)\s*$/$1/gxms;             # strip trailing whitespace, caused by grammar matching operator names with trailing spaces
 
                 if ( $property_name ne $property_key ) {
                     die 'ERROR ECOGEASRP20, CODE GENERATOR, ABSTRACT SYNTAX TO RPERL: redundant name mismatch, inner type name ' . q{'}
@@ -480,7 +480,7 @@ EOL
         my object $properties_1_to_n = $properties->{children}->[4];
 
         my string $property_key = $property_0->{children}->[0]->{children}->[0];
-        $property_key =~ s/^(\w+)\s*$/$1/gxms;    # remove trailing whitespace, caused by grammar matching operator names with trailing spaces
+        $property_key =~ s/^(\w+)\s*$/$1/gxms;    # strip trailing whitespace, caused by grammar matching operator names with trailing spaces
         if ( $property_key !~ /^[a-z]/ ) {
             die 'ERROR ECOGEASCP23, CODE GENERATOR, ABSTRACT SYNTAX TO C++: invalid OO properties name (hash key) ' . q{'}
                 . $property_key . q{'}
@@ -491,7 +491,7 @@ EOL
         my object $property_subexpression      = undef;
         my object $property_arrayref_index_max = undef;
         my string $property_name               = $property_type_inner->{children}->[3]->{children}->[0];
-        $property_name =~ s/^(\w+)\s*$/$1/gxms;    # remove trailing whitespace, caused by grammar matching operator names with trailing spaces
+        $property_name =~ s/^(\w+)\s*$/$1/gxms;    # strip trailing whitespace, caused by grammar matching operator names with trailing spaces
 
         # DEV NOTE: we can do error checking once here instead of twice for TypeInnerProperties_223 & TypeInnerProperties_224 below
         # because they both have OpStringOrWord as sub-element 3, grabbed as $property_name above
@@ -581,7 +581,7 @@ EOL
             $property_arrayref_index_max = undef;
 
             $property_key = $property->{children}->[0]->{children}->[0];
-            $property_key =~ s/^(\w+)\s*$/$1/gxms;      # remove trailing whitespace, caused by grammar matching operator names with trailing spaces
+            $property_key =~ s/^(\w+)\s*$/$1/gxms;      # strip trailing whitespace, caused by grammar matching operator names with trailing spaces
             if ( $property_key !~ /^[a-z]/ ) {
                 die 'ERROR ECOGEASCP23, CODE GENERATOR, ABSTRACT SYNTAX TO C++: invalid OO properties name (hash key) ' . q{'}
                     . $property_key . q{'}
@@ -589,7 +589,7 @@ EOL
             }
             $property_type_inner = $property->{children}->[2];
             $property_name       = $property_type_inner->{children}->[3]->{children}->[0];
-            $property_name =~ s/^(\w+)\s*$/$1/gxms;     # remove trailing whitespace, caused by grammar matching operator names with trailing spaces
+            $property_name =~ s/^(\w+)\s*$/$1/gxms;     # strip trailing whitespace, caused by grammar matching operator names with trailing spaces
 
             # DEV NOTE: we can do error checking once here instead of twice for TypeInnerProperties_223 & TypeInnerProperties_224 below
             # because they both have OpStringOrWord as sub-element 3, grabbed as $property_name above
