@@ -53,7 +53,7 @@ our string_hashref::method $ast_to_rperl__generate = sub {
 
     if ( ( $self_class ) ne 'ArrayReference_196' ) {
         die RPerl::Parser::rperl_rule__replace(
-            'ERROR ECVGEASRP00, CODE GENERATOR, ABSTRACT SYNTAX TO RPERL: grammar rule '
+            'ERROR ECOGEASRP00, CODE GENERATOR, ABSTRACT SYNTAX TO RPERL: grammar rule '
                 . ( $self_class )
                 . ' found where ArrayReference_196 or SubExpression_138 expected, dying' )
             . "\n";
@@ -107,7 +107,7 @@ our string_hashref::method $ast_to_cpp__generate__CPPOPS_CPPTYPES = sub {
 
     if ( ( $self_class ) ne 'ArrayReference_196' ) {
         die RPerl::Parser::rperl_rule__replace(
-            'ERROR ECVGEASCP00, CODE GENERATOR, ABSTRACT SYNTAX TO C++: grammar rule '
+            'ERROR ECOGEASCP00, CODE GENERATOR, ABSTRACT SYNTAX TO C++: grammar rule '
                 . ( $self_class )
                 . ' found where ArrayReference_196 or SubExpression_138 expected, dying' )
             . "\n";
