@@ -23,12 +23,13 @@ our void $right_justify_20 = sub {
     }
 
     print "\n";
-    print '1234567890'x 6;
+    print '1234567890' x 6;
     print "\n";
 
     foreach my string $input_string ( @{$input_strings} ) {
-        print q{ }x ( 21 - ( length $input_string ) );
-        print $input_string;
+        chomp $input_string;
+        print q{ } x ( 20 - ( length $input_string ) );
+        print $input_string . "\n";
     }
 };
 
