@@ -2,7 +2,7 @@
 package RPerl::Operation::Expression::Operator::List;
 use strict;
 use warnings;
-use RPerl;
+use RPerl::AfterSubclass;
 our $VERSION = 0.001_000;
 
 # [[[ OO INHERITANCE ]]]
