@@ -1,14 +1,16 @@
 # [[[ HEADER ]]]
+use RPerl;
 package RPerl::Test::LiteralNumber::Package_42_Good;
 use strict;
 use warnings;
-use RPerl;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return 234_567.234_56; };
+our number $empty_sub = sub {
+    return 234_567.234_56;
+};
 
-1;                  # end of package
+1;    # end of package
