@@ -1,11 +1,13 @@
 # [[[ HEADER ]]]
+use RPerl;
 package RPerl::Test::LiteralString::Package_SingleQuotes_01_Good;
 use strict;
 use warnings;
-use RPerl;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return 'foo123'; };
+our string $empty_sub = sub {
+    return 'foo123';
+};
 
-1;                  # end of package
+1;    # end of package
